==> 0.6.1.tar.gz: lib/utils/basicInfo.dart <==



class BasicInfo {
  late int userId;
  late int businessId;
  late String baseUrl;
  late String currencySymbol;
  late String userName;
  late String appLanguageCode;
  late String userImage;
  late String baseUrlWithoutHttp;
  late String timeFormat;
  late String token ;
  late String dateFormat;
  late String googleTransltionKey;
  late String googleMapKey;
  final String statusCode = "S10001";
  final String statusCodeEmpty = "S10003";

  final String createRewards ='/api/v1/business/loyalty/program/create';
  final String welcomeMessage = '/api/v1/business/welcome/message/list';
  final String dynamicImageUrl='/api/v1/file/media/read';
  final String createPost='/api/v1/post/create';
  final  String partnerList='/api/v2/business/partner/list';
  final String mediaFiles='/api/v1/file/media/list';
  final String translate = 'https://translation.googleapis.com/language/translate/v2';
  final String loyaltyTypeAdd = '/api/v1/standard/loyaltytype/customize';
  final String loyaltyProgramList = '/api/v1/business/loyalty/program/list';

  final String dafoultRedemption = '/api/v1/business/redemption/settings/view';
  final String fetchCashCoinData = '/api/v1/aaa/tax/details';
  final String loyaltyTypeList = '/api/v1/standard/loyaltyprogramtype/list';
  final String postReceiversList = '/api/v2/utility/recipienttype/list';
  final String personList = '/api/v1/standard/persontype/list';
  final String countryList = '/api/v1/business/partner/addresss/entities';
  final  String couponPurchase = '/api/v1/reward/purchasecoupons';
  final String editReward = '/api/v1/business/loyalty/program/update';
  final String deleteReward = '/api/v1/business/loyalty/program/status/update';
  final String couponDetails = '/api/v1/reward/balancedetails';

  final String dafoultRedemptionUpdate = '/api/v1/business/redemption/settings/update';
  final String loyaltyList='/api/v1/standard/loyaltytype/list';
  final String rewardCouponList =  '/api/v1/reward/couponlist';
   final String myCouponList = '/api/v1/reward/mycouponlist';
  final String countries = '/api/v1/rl/countries/';
  final String states = '/api/v1/rl/states/';

  final String location = '/api/v1/business/location/detail';
  final String addLocation = '/api/v1/business/location/register/';

  final String updateBank =
  '/api/v1/utility/bank/details/update';

  final String bankDetail =
    '/api/v1/utility/bank/details/view';
  final String businessAcountEdit =
   '/api/v1/business/accounting/edit';

  final String accountRegister =
'/api/v1/business/accounting/register';
  final String userProfile ='/api/v1/business/profile';

  final String editLocation = '/api/v1/business/location/edit';
  final String couponLeaderList = '/api/v1/reward/ledgerlist';
  final String createOrder = '/api/v1/aaa/order/create';

  final String cartView = '/api/v1/aaa/cart/view';
  final String cartCreate='/api/v1/aaa/cart/update';


  static final BasicInfo _instance =  BasicInfo._internal();
  BasicInfo._internal() ;
  factory BasicInfo() {
    return _instance;
  }
}

==> 0.8.1.tar.gz: lib/utils/basicInfo.dart <==



class BasicInfo {
  late int userId;
  late int businessId;
  late String baseUrl;
  late String currencySymbol;
  late String userName;
  late String appLanguageCode;
  late String userImage;
  late String baseUrlWithoutHttp;
  late String timeFormat;
  late String token ;
  late String dateFormat;
  late String googleTransltionKey;
  late String googleMapKey;
 late Function callBack;
  final String statusCode = "S10001";
  final String statusCodeEmpty = "S10003";

  final String createRewards ='/api/v1/business/loyalty/program/create';
  final String welcomeMessage = '/api/v1/business/welcome/message/list';
  final String dynamicImageUrl='/api/v1/file/media/read';
  final String createPost='/api/v1/post/create';
  final  String partnerList='/api/v2/business/partner/list';
  final String mediaFiles='/api/v1/file/media/list';
  final String translate = 'https://translation.googleapis.com/language/translate/v2';
  final String loyaltyTypeAdd = '/api/v1/standard/loyaltytype/customize';
  final String loyaltyProgramList = '/api/v1/business/loyalty/program/list';

  final String dafoultRedemption = '/api/v1/business/redemption/settings/view';
  final String fetchCashCoinData = '/api/v1/aaa/tax/details';
  final String loyaltyTypeList = '/api/v1/standard/loyaltyprogramtype/list';
  final String postReceiversList = '/api/v2/utility/recipienttype/list';
  final String personList = '/api/v1/standard/persontype/list';
  final String countryList = '/api/v1/business/partner/addresss/entities';
  final  String couponPurchase = '/api/v1/reward/purchasecoupons';
  final String editReward = '/api/v1/business/loyalty/program/update';
  final String deleteReward = '/api/v1/business/loyalty/program/status/update';
  final String couponDetails = '/api/v1/reward/balancedetails';
  final String settingView = '/api/v1/aaa/recharge/min/settings/view';


  final String dafoultRedemptionUpdate = '/api/v1/business/redemption/settings/update';
  final String loyaltyList='/api/v1/standard/loyaltytype/list';
  final String rewardCouponList =  '/api/v1/reward/couponlist';
   final String myCouponList = '/api/v1/reward/mycouponlist';
  final String countries = '/api/v1/rl/countries/';
  final String states = '/api/v1/rl/states/';

  final String location = '/api/v1/business/location/detail';
  final String addLocation = '/api/v1/business/location/register/';

  final String updateBank =
  '/api/v1/utility/bank/details/update';

  final String bankDetail =
    '/api/v1/utility/bank/details/view';
  final String businessAcountEdit =
   '/api/v1/business/accounting/edit';

  final String accountRegister =
'/api/v1/business/accounting/register';
  final String userProfile ='/api/v1/business/profile';

  final String editLocation = '/api/v1/business/location/edit';
  final String couponLeaderList = '/api/v1/reward/ledgerlist';
  final String createOrder = '/api/v1/aaa/order/create';
  final String updatePaymentStatus = '/api/v1/aaa/order/paymentstatus/update';
  final String cartView = '/api/v1/aaa/cart/view';
  final String createCart='/api/v1/aaa/cart/update';

  final String paymentToken='/api/v1/aaa/order/get/payment/token';




  static final BasicInfo _instance =  BasicInfo._internal();
  BasicInfo._internal() ;
  factory BasicInfo() {
    return _instance;
  }
}
